==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitContainer.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack.*;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.config.MaidConfigContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.WirelessIOContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.task.AttackTaskConfigContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.task.DefaultMaidTaskConfigContainer;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3917;
import net.minecraft.class_7923;

public final class InitContainer {
    public static void init() {

    }

    public static final class_3917<EmptyBackpackContainer> MAID_EMPTY_BACKPACK_CONTAINER = register("maid_empty_backpack_container", EmptyBackpackContainer.TYPE);
    public static final class_3917<SmallBackpackContainer> MAID_SMALL_BACKPACK_CONTAINER = register("maid_small_backpack_container", SmallBackpackContainer.TYPE);
    public static final class_3917<MiddleBackpackContainer> MAID_MIDDLE_BACKPACK_CONTAINER = register("maid_middle_backpack_container", MiddleBackpackContainer.TYPE);
    public static final class_3917<BigBackpackContainer> MAID_BIG_BACKPACK_CONTAINER = register("maid_big_backpack_container", BigBackpackContainer.TYPE);
    public static final class_3917<CraftingTableBackpackContainer> MAID_CRAFTING_TABLE_BACKPACK_CONTAINER = register("maid_crafting_table_backpack_container", CraftingTableBackpackContainer.TYPE);
    public static final class_3917<EnderChestBackpackContainer> MAID_ENDER_CHEST_CONTAINER = register("maid_ender_chest_container", EnderChestBackpackContainer.TYPE);
    public static final class_3917<FurnaceBackpackContainer> MAID_FURNACE_CONTAINER = register("maid_furnace_container", FurnaceBackpackContainer.TYPE);
    public static final class_3917<TankBackpackContainer> MAID_TANK_CONTAINER = register("maid_tank_container", TankBackpackContainer.TYPE);

    public static final class_3917<MaidConfigContainer> MAID_CONFIG_CONTAINER = register("maid_config_container", MaidConfigContainer.TYPE);
    public static final class_3917<WirelessIOContainer> WIRELESS_IO_CONTAINER = register("wireless_io_container", WirelessIOContainer.TYPE);
    public static final class_3917<PicnicBasketContainer> PICNIC_BASKET_CONTAINER = register("picnic_basket_container", PicnicBasketContainer.TYPE);
    public static final class_3917<DefaultMaidTaskConfigContainer> DEFAULT_MAIK_TASK_CONFIG = register("default_maid_task_config_container", DefaultMaidTaskConfigContainer.TYPE);
    public static final class_3917<AttackTaskConfigContainer> ATTACK_TASK_CONFIG = register("attack_task_config_container", AttackTaskConfigContainer.TYPE);

    private static <T extends class_3917<?>> T register(String id, T type) {
        return class_2378.method_10230(class_7923.field_41187, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), type);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.3-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitContainer.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack.*;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.config.MaidAIChatConfigContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.config.MaidConfigContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.WirelessIOContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.task.AttackTaskConfigContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.task.DefaultMaidTaskConfigContainer;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3917;
import net.minecraft.class_7923;

public final class InitContainer {
    public static void init() {

    }

    public static final class_3917<EmptyBackpackContainer> MAID_EMPTY_BACKPACK_CONTAINER = register("maid_empty_backpack_container", EmptyBackpackContainer.TYPE);
    public static final class_3917<SmallBackpackContainer> MAID_SMALL_BACKPACK_CONTAINER = register("maid_small_backpack_container", SmallBackpackContainer.TYPE);
    public static final class_3917<MiddleBackpackContainer> MAID_MIDDLE_BACKPACK_CONTAINER = register("maid_middle_backpack_container", MiddleBackpackContainer.TYPE);
    public static final class_3917<BigBackpackContainer> MAID_BIG_BACKPACK_CONTAINER = register("maid_big_backpack_container", BigBackpackContainer.TYPE);
    public static final class_3917<CraftingTableBackpackContainer> MAID_CRAFTING_TABLE_BACKPACK_CONTAINER = register("maid_crafting_table_backpack_container", CraftingTableBackpackContainer.TYPE);
    public static final class_3917<EnderChestBackpackContainer> MAID_ENDER_CHEST_CONTAINER = register("maid_ender_chest_container", EnderChestBackpackContainer.TYPE);
    public static final class_3917<FurnaceBackpackContainer> MAID_FURNACE_CONTAINER = register("maid_furnace_container", FurnaceBackpackContainer.TYPE);
    public static final class_3917<TankBackpackContainer> MAID_TANK_CONTAINER = register("maid_tank_container", TankBackpackContainer.TYPE);

    public static final class_3917<MaidConfigContainer> MAID_CONFIG_CONTAINER = register("maid_config_container", MaidConfigContainer.TYPE);
    public static final class_3917<MaidAIChatConfigContainer> MAID_AI_CHAT_CONFIG_CONTAINER = register("maid_ai_chat_config_container", MaidAIChatConfigContainer.TYPE);
    public static final class_3917<WirelessIOContainer> WIRELESS_IO_CONTAINER = register("wireless_io_container", WirelessIOContainer.TYPE);
    public static final class_3917<PicnicBasketContainer> PICNIC_BASKET_CONTAINER = register("picnic_basket_container", PicnicBasketContainer.TYPE);
    public static final class_3917<DefaultMaidTaskConfigContainer> DEFAULT_MAIK_TASK_CONFIG = register("default_maid_task_config_container", DefaultMaidTaskConfigContainer.TYPE);
    public static final class_3917<AttackTaskConfigContainer> ATTACK_TASK_CONFIG = register("attack_task_config_container", AttackTaskConfigContainer.TYPE);

    private static <T extends class_3917<?>> T register(String id, T type) {
        return class_2378.method_10230(class_7923.field_41187, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), type);
    }
}
